---
title: strategy
sidebarTitle: strategy
---

# `catalax.neural.strategy`

## Classes

### `Modes` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/strategy.py#L18" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

### `Step` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/strategy.py#L24" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

### `Strategy` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/strategy.py#L119" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

**Methods:**

#### `add_step` <sup><a href="https://github.com/JR-1991/Catalax/blob/master/catalax/neural/strategy.py#L123" target="_blank"><Icon icon="github" style="width: 14px; height: 14px;" /></a></sup>

```python
add_step(self, lr: float, steps: int, batch_size: int, length: float = 1.0, penalties: Penalties = Penalties(), loss: Any = optax.l2_loss, train: Modes = Modes.MLP)
```
